@@ -5,7 +5,7 @@ package Module::Install::ExtraTests;
 use Module::Install::Base;
 
 BEGIN {
-  our $VERSION = '0.002';
+  our $VERSION = '0.003';
   our $ISCORE  = 1;
   our @ISA     = qw{Module::Install::Base};
 }
@@ -24,7 +24,8 @@ sub extra_tests {
 
   {
     no warnings qw(closure once);
-    package MY;
+    package # The newline tells PAUSE, "DO NOT INDEXING!"
+    MY;
     sub test_via_harness {
       my ($self, $perl, $tests) = @_;
       my $a_str = -d 'xt/author'  ? 'xt/author'  : '';
@@ -33,7 +34,7 @@ sub extra_tests {
       my $is_author = $Module::Install::AUTHOR ? 1 : 0;
 
       return qq{\t$perl "-Iinc" "-MModule::Install::ExtraTests" }
-           . qq{"-e" "Module::Install::ExtraTests::__harness('Test::Harness', $is_author, '$a_str', '$r_str', '$s_str', \$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCH LIB)')" $tests\n};
+           . qq{"-e" "Module::Install::ExtraTests::__harness('Test::Harness', $is_author, '$a_str', '$r_str', '$s_str', \$(TEST_VERBOSE), '\$(INST_LIB)', '\$(INST_ARCHLIB)')" $tests\n};
     }
 
     sub dist_test {
